from sqlalchemy import *
from migrate import *


def getDocument(meta):
    return Table('document', meta, autoload=True)

def getFiscalDocumentTable(meta):
    return Table('fiscaldocument', meta,
        Column('fiscaldocumentid', Integer, nullable=False, primary_key=True, autoincrement=True),
        Column('documentid', Integer, ForeignKey(getDocument(meta).c.documentid, name='ficaldocumentdocumentidfk',
               ondelete='CASCADE'), nullable=False),
        Column('fnnumber', String(255), nullable=False),
        Column('serialnum', String(255), nullable=False),
        Column('fdnumber', Integer, nullable=False),
        Column('taxsystem', String(100), nullable=True),
        Column('shiftnumber', String(100), nullable=False),
        Column('sum', Numeric(precision=13, scale=2), nullable=False), 
        Column('hasofdticket', Boolean, nullable=False),
        Column('fndate', DateTime, nullable=False),
        Column('ofddate', DateTime, nullable=True),
        Column('fiscalsign', String(255), nullable=False),
        Column('ofdfiscalsign', String(255), nullable=True),
        UniqueConstraint('documentid', 'fnnumber', 'fdnumber', name='fiscaldocumentunique'),
        mysql_engine='InnoDB'
    )

def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    fiscalDocumentTable = getFiscalDocumentTable(meta)
    if not fiscalDocumentTable.exists(meta.bind):
        fiscalDocumentTable.create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    fiscalDocumentTable = getFiscalDocumentTable(meta)
    if fiscalDocumentTable.exists(meta.bind):
        fiscalDocumentTable.drop()
